@@ -123,7 +123,7 @@ class Button(BaseWidget):
             justify = justify,
             background_color = background_color,
             #"highlightbackground_color":"cyan",
-            # "highlightthickness":5,
+            highlightthickness = 0,
             highlightcolor = highlightcolor,
             relief = relief,
             text_color = text_color,
@@ -237,5 +237,6 @@ class Button(BaseWidget):
         self.tk_widget.invoke()
 
     def init_window_creation_done(self):
+        super().init_window_creation_done()
         if self._disabled_at_start:
             self._update_initial(disabled=True)
